@@ -1,5 +1,5 @@
 <?php
-/* $Id: catalan-iso-8859-1.inc.php 10558 2007-08-11 23:52:58Z lem9 $ */
+/* $Id: catalan-iso-8859-1.inc.php 11159 2008-03-07 17:59:01Z lem9 $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' d'esquerra a dreta, 'rtl' de dreta a esquerra)
@@ -356,8 +356,8 @@ $strImportSuccessfullyFinished = 'Importaci finalitzada correctament, %d consult
 $strIndexes = 'Indexos';
 $strIndexesSeemEqual = 'Els seguents indexos semblen iguals i un d\'ells s\'ha d\'esborrar:';
 $strIndexHasBeenDropped = 'S\'ha esborrat l\'ndex %s';
-$strIndex = 'ndex';
 $strIndexName = 'Nom d\'ndex:';
+$strIndex = 'ndex';
 $strIndexType = 'Tipus d\'ndex:';
 $strIndexWarningTable = 'Problemes amb els index de la taula `%s`';
 $strInnoDBAutoextendIncrementDesc = ' La quantitat a incrementar per ampliar el tamany d\'una taula autoextensible quan estigui a punt d\'omplir-se.';
@@ -1020,4 +1020,8 @@ $strYes = 'Si';
 $strZeroRemovesTheLimit = 'Nota: Es treu el limit establint aquestes opcions a 0 (zero).';
 $strZip = '"comprimit amb zip"';
 
+// To translate:
+
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
+
 ?>
