@@ -1,9 +1,9 @@
 <?php
-/* $Id: croatian-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
+/* $Id: croatian-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 /**
  *   Croatian language file by
- *   Renato Pavičić <renato@translator-shop.org>
+ *   Renato Pavičić <renato<at>translator-shop.org>
  */
 
 $charset = 'utf-8';
@@ -21,6 +21,7 @@ $month = array('Sij', 'Velj', 'Ožu', 'Tra', 'Svi', 'Lip', 'Srp', 'Kol', 'Ruj',
 $datefmt = '%B %d, %Y u %I:%M %p';
 $timespanfmt = '%s dana, %s sati, %s minuta i %s sekunda';
 
+
 $strAbortedClients = 'Prekinuto';
 $strAccessDeniedCreateConfig = 'Vjerojatan razlog je nepostojeća konfiguracijska datoteka. Za izradu možete upotrijebiti naredbu %1$ssetup script%2$s';
 $strAccessDeniedExplanation = 'phpMyAdmin pokušao je uspostaviti vezu s MySQL poslužiteljem, ali je poslužitelj odbio povezivanje. U datoteci config.inc.php provjerite naziv računala, korisničko ime i lozinku, te provjerite da se odgovaraju podacima koje vam je dao administrator MySQL poslužitelja.';
@@ -55,6 +56,7 @@ $strAlterOrderBy = 'Izmijeni rasporede tablice po';
 $strAnalyzeTable = 'Analiziraj tablicu';
 $strAnd = 'I';
 $strAndThen = 'i potom';
+$strAngularLinks = 'Kutne veze';
 $strAnIndex = 'Indeks je pridodan na %s';
 $strAny = 'Bilo koji';
 $strAnyHost = 'Bilo koje računalo';
@@ -106,6 +108,7 @@ $strBzError = 'phpMyAdmin nije bio u mogućnosti komprimirati izbacivanje zbog p
 $strBzip = '"bzipano"';
 
 $strCalendar = 'Kalendar';
+$strCancel = 'Odustani';
 $strCanNotLoadExportPlugins = 'Nije moguće učitati dodatke za izvoz. Provjerite svoju instalaciju!';
 $strCanNotLoadImportPlugins = 'Nije moguće učitati dodatke za uvoz. Provjerite svoju instalaciju!';
 $strCannotLogin = 'Prijavljivanje na MySQL poslužitelj nije moguće';
@@ -154,6 +157,7 @@ $strConnectionError = 'Povezivanje nije moguće: neispravna postavka.';
 $strConnections = 'Veze';
 $strConstraintsForDumped = 'Ograničenja za izbačene tablice';
 $strConstraintsForTable = 'Ograničenja za tablicu';
+$strControluserFailed = 'Povezivanje kontrolnih korisnika na način kako je definirano u vašoj konfiguraciji nije uspjelo.';
 $strCookiesRequired = 'Od ovog mjesta potrebno je omogućiti kolačiće.';
 $strCopyDatabaseOK = 'Baza podataka %s kopirana je u %s';
 $strCopy = 'Kopiraj';
@@ -169,6 +173,8 @@ $strCreateNewDatabase = 'Izradi novu bazu podataka';
 $strCreateNewTable = 'Izradi novu tablicu u bazi podataka %s';
 $strCreatePage = 'Izradi novu stranicu';
 $strCreatePdfFeat = 'Izrada PDF datoteka';
+$strCreateRelation = 'Izradi povezanost';
+$strCreateTable  = 'Izradi tablicu';
 $strCreateUserDatabase = 'Baza podataka za korisnika';
 $strCreateUserDatabaseName = 'Izradi bazu podataka istog naziva i podari sve privilegije';
 $strCreateUserDatabaseNone = 'Nijedan';
@@ -198,6 +204,7 @@ $strDataPages = 'Stranice koje sadrže podatke';
 $strData = 'Podaci';
 $strDBComment = 'Komentar baze podataka:  ';
 $strDBCopy = 'Kopiraj bazu podataka u';
+$strDbIsEmpty = 'Baza podataka izgleda praznom!';
 $strDbPrivileges = 'Privilegije specifične za bazu podataka';
 $strDBRename = 'Preimenuj bazu podataka u';
 $strDbSpecific = 'specifično za bazu podataka';
@@ -212,12 +219,16 @@ $strDeleted = 'Redak je izbrisan';
 $strDeletedRows = 'Izbrisani redovi:';
 $strDelete = 'Izbriši';
 $strDeleteNoUsersSelected = 'Nema odabranih korisnika za uklanjanje!';
+$strDeleteRelation = 'Izbriši povezanost';
 $strDeleting = 'Brisanje %s';
 $strDelimiter = 'Razgraničavanje';
 $strDelOld = 'Trenutna stranica sadrži reference prema tablicama koje više ne postoje. Želite li izbrisati te reference?';
 $strDescending = 'Silazno';
 $strDescription = 'Opis';
+$strDesignerHelpDisplayField = 'Polje pregledavanja prikazano je u rozoj boji. Kako biste za polje odabrali ili uklonili opciju polja za prikazivanje kliknite ikonu "Odaberite polje za prikazivanje", a zatim kliknite odgovarajući naziv polja.';
+$strDesigner = 'Kreator';
 $strDictionary = 'rječnik';
+$strDirectLinks = 'Izravne veze';
 $strDirtyPages = 'Prljave stranice';
 $strDisabled = 'Onemogućeno';
 $strDisableForeignChecks = 'Onemogući provjere stranih znakova';
@@ -225,6 +236,7 @@ $strDisplayFeat = 'Osobine prikaza';
 $strDisplayOrder = 'Redoslijed prikaza:';
 $strDisplayPDF = 'Prikaži PDF shemu';
 $strDoAQuery = 'Izvedi "upit po primjeru" (džoker: "%")';
+$strDocSQL = 'DocSQL';
 $strDocu = 'Dokumentacija';
 $strDoYouReally = 'Želite li zaista  ';
 $strDropDatabaseStrongWarning = 'UNIŠTIT ĆETE CJELOKUPNU BAZU PODATAKA!';
@@ -254,13 +266,18 @@ $strEnglish = 'Engleski';
 $strEnglishPrivileges = ' Napomena: Nazivi MySQL privilegija navedeni su na engleskom jeziku ';
 $strErrorInZipFile = 'Pogreška u ZIP arhivi:';
 $strError = 'Pogreška';
+$strErrorRelationAdded = 'Pogreška: Povezanost nije dodana.';
+$strErrorRelationExists = 'Pogreška: Povezanost već postoji.';
 $strErrorRenamingTable = 'Pogreška tijekom preimenovanja tablice %1$s u %2$s';
+$strErrorSaveTable = 'Pogreška tijekom spremanja koordinata za Kreatora.';
 $strEscapeWildcards = 'Da bi mogli biti upotrebljavani u doslovnom smislu, džokerima \_ i \% mora prethoditi znak \\';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonski';
+$strEvent = 'Događaj';
 $strExcelEdition = 'Excel izdanje';
 $strExecuteBookmarked = 'Izvrši favorizirani upit';
 $strExplain = 'Objasni SQL';
+$strExportImportToScale = 'Uvoz / Izvor prema omjeru';
 $strExport = 'Izvoz';
 $strExportMustBeFile = 'Odabrana vrsta izvoza mora biti spremljena u datoteku!';
 $strExtendedInserts = 'Proširena umetanja';
@@ -268,6 +285,7 @@ $strExtra = 'Dodatno';
 
 $strFailedAttempts = 'Neuspjeli pokušaji';
 $strFieldHasBeenDropped = 'Polje %s je odbačeno';
+$strFieldInsertFromFileTempDirNotExists = 'Pogreška tijekom premještanja učitane datoteke. Pogledajte ČPP 1.11';
 $strField = 'Polje';
 $strFieldsEnclosedBy = 'Polja obuhvaćena po';
 $strFieldsEscapedBy = 'Polja izostavljena po';
@@ -281,6 +299,7 @@ $strFileNameTemplateDescriptionTable = 'naziv tablice';
 $strFileNameTemplateDescription = 'Vrijednost se interpretira pomoću %1$sstrftime%2$s, pa možete upotrijebiti naredbe oblikovanja vremena. Dodatno se mogu dogoditi sljedeća preoblikovanja: "%3$s". Ostatak teksta bit će zadržan u izvornom obliku.';
 $strFileNameTemplate = 'Predložak naziva datoteka';
 $strFileNameTemplateRemember = 'zapamti predložak';
+$strFiles = 'Datoteke';
 $strFileToImport = 'Datoteka za uvoz';
 $strFixed = 'fiksirano';
 $strFlushPrivilegesNote = 'Napomena: phpMyAdmin preuzima korisničke privilegije izravno iz MySQL tablica privilegija. U slučaju da su ručno mijenjane, sadržaj ovih tablica može se razlikovati od privilegija koje upotrebljava poslužitelj. U tom je slučaju potrebno %sponovo učitati privilegije%s prije nastavljanja rada.';
@@ -288,6 +307,7 @@ $strFlushQueryCache = 'Isprazni pohranu upita';
 $strFlushTable = 'Isprazni tablicu ("FLUSH")';
 $strFlushTables = 'Isprazni (zatvori) sve tablice';
 $strFontSize = 'Veličina fonta';
+$strForeignKeyError = 'Pogreška tijekom izrade stranog ključa (provjerite vrste podataka)';
 $strFormat = 'Oblikovanje';
 $strFormEmpty = 'U obrascu nedostaje vrijednost!';
 $strFreePages = 'Slobodne stranice';
@@ -315,6 +335,11 @@ $strHasBeenAltered = 'izmijenjeno je.';
 $strHasBeenCreated = 'izrađeno je.';
 $strHaveToShow = 'Morate odabrati najmanje jedan stupac za prikazivanje';
 $strHebrew = 'Hebrejski';
+$strHelp = 'Pomoć';
+$strHexForBLOB = 'Za BLOB upotrijebi heksadecimalno';
+$strHide         = 'Sakrij';
+$strHideShowAll = 'Prikaži / Sakrij sve';
+$strHideShowNoRelation = 'Prikaži / Sakrij tablice bez povezanosti';
 $strHomepageOfficial = 'Službena stranica programa phpMyAdmin';
 $strHome = 'Početna stranica';
 $strHostEmpty = 'Naziv računala je prazan!';
@@ -326,14 +351,17 @@ $strHungarian = 'Mađarski';
 $strIcelandic = 'Islandski';
 $strId = 'ID';
 $strIdxFulltext = 'Puni tekst';
+$strIEUnsupported = 'Internet Explorer ne podržava ovu funkciju.';
 $strIgnoreDuplicates = 'Ignoriraj istovjetne redove';
 $strIgnore = 'Ignoriraj';
 $strIgnoreInserts = 'Upotrijebi ignoriranje umetaka';
+$strImportExportCoords = 'Uvoz / Izvoz koordinate iz PDF sheme';
 $strImportFiles = 'Uvezi datoteke';
 $strImportFormat = 'Oblikovanje uvezene datoteke';
 $strImportSuccessfullyFinished = 'Uvoz je uspješno dovršen. Izvršeno upita: %d .';
 $strImport = 'Uvoz';
 $strIndexes = 'Indeksi';
+$strIndexesSeemEqual = 'Sljedeći indeksi izgledaju jednakim i jednog je potrebno ukloniti:';
 $strIndexHasBeenDropped = 'Index %s je odbačen';
 $strIndex = 'Indeks';
 $strIndexName = 'Naziv indeksa:';
@@ -347,6 +375,7 @@ $strInnoDBDataFilePath = 'Podatkovne datoteke';
 $strInnoDBDataHomeDirDesc = 'Uobičajeni dio putanje mapa za sve InnoDB podatkovne datoteke.';
 $strInnoDBDataHomeDir = 'Osnovna mapa podataka';
 $strInnoDBPages = 'stranice';
+$strInnoDBRelationAdded = 'Dodana InnoDB povezanosti';
 $strInnodbStat = 'InnoDB stanje';
 $strInsecureMySQL = 'Vaša konfiguracijska datoteka sadrži postavke (root korisnik bez lozinke) koja odgovara zadanom privilegiranom nalogu MySQL-a. Vaš MySQL poslužitelj pokrenut je sa zadanim postavkama i kao takav otvoren je upadima. Potrebno je ispraviti ovaj sigurnosni nedostatak.';
 $strInsertAsNewRow = 'Umetni kao novi redak';
@@ -354,6 +383,7 @@ $strInsertedRowId = 'ID umetnutog retka:';
 $strInsertedRows = 'Umetnuti redovi:';
 $strInsert = 'Umetni';
 $strInternalNotNecessary = '* Interna relacija nije potrebna ako također postoji unutar InnoDB.';
+$strInternalRelationAdded = 'Dodane interne povezanosti';
 $strInternalRelations = 'Interne relacije';
 $strInUse = 'u upotrebi';
 $strInvalidAuthMethod = 'Neispravan komplet načina provjere vjerodostojnosti u konfiguraciji:';
@@ -381,6 +411,7 @@ $strKeepPass = 'Ne mijenjaj lozinku';
 $strKeyCache = 'Pohrana ključeva';
 $strKeyname = 'Naziv ključa';
 $strKill = 'Eliminiraj';
+$strKnownExternalBug = 'Na funkcionalnost %s utječe poznati nedostatak. Pogledajte %s';
 $strKorean = 'Korejski';
 
 $strLandscape = 'Položeno';
@@ -433,6 +464,7 @@ $strMIME_without = 'MIME vrste ispisane kurzivom nemaju posebnu funkciju preobli
 $strModifications = 'Izmjene su spremljene';
 $strModifyIndexTopic = 'Uredi indeks';
 $strModify = 'Uredi';
+$strMoveMenu = 'Premjesti izbornik';
 $strMoveTableOK = 'Tablica %s premještena je u %s.';
 $strMoveTable = 'Premjesti tablicu u (bazapodataka<b>.</b>tablica):';
 $strMoveTableSameNames = 'Premještanje u istu tablicu nije moguće!';
@@ -452,6 +484,7 @@ $strMyISAMSortBufferSize = 'Veličina međuspremnika preslagivanja';
 $strMySQLCharset = 'MySQL tablica znakova';
 $strMysqlClientVersion = 'MySQL verzija klijenta';
 $strMySQLConnectionCollation = 'MySQL uspoređivanje veza';
+$strMysqlLibDiffersServerVersion = 'Verzija %s vaše PHP MySQL biblioteke razlikuje se oda vaše verzije %s MySQL poslužitelja. Ovo bi moglo prouzrokovati nepredviđeno ponašanje.';
 $strMySQLSaid = 'MySQL je poručio:  ';
 $strMySQLShowProcess = 'Prikaži procese';
 $strMySQLShowStatus = 'Prikaži podatke MySQL pokretanja';
@@ -491,6 +524,7 @@ $strNoUsersFound = 'Korisnici nisu pronađeni.';
 $strNoValidateSQL = 'Preskoči provjeru valjanosti SQL-a';
 $strNull = 'Null';
 $strNumberOfFields = 'Broj polja';
+$strNumberOfTables = 'Broj tablica';
 $strNumSearchResultsInTable = '%s poklapanja unutar tablice <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Ukupno:</b> <i>%s</i> poklapanja';
 $strNumTables = 'Tablice';
@@ -502,6 +536,7 @@ $strOpenNewWindow = 'Otvori novi phpMyAdmin prozor';
 $strOperations = 'Operacije';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimiziraj tablicu';
+$strOptions = 'Opcije';
 $strOr = 'Ili';
 $strOverhead = 'Prepunjenje';
 $strOverwriteExisting = 'Prepiši postojeće datoteke';
@@ -530,8 +565,10 @@ $strPhoneBook = 'telefonski imenik';
 $strPHP40203 = 'Upotrebljavate PHP 4.2.3 koji ima ozbiljne poteškoće s nizovima od višestrukih bajtova (mbstring). Pogledajte PHP izvještaj o nedostatku 19404. Ne preporučuje se upotreba ove verzije PHP-a uz program phpMyAdmin.';
 $strPhp = 'Izradi PHP kod';
 $strPHPVersion = 'PHP verzija';
+$strPleaseSelectPrimaryOrUniqueKey = 'Odaberite primarni ključ ili jedinstveni ključ';
 $strPmaDocumentation = 'phpMyAdmin dokumentacija';
 $strPmaUriError = 'Direktiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> MORA BITI postavljena u vašoj konfiguracijskoj datoteci!';
+$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Poljski';
 $strPortrait = 'Portret';
 $strPos1 = 'Na vrh stranice';
@@ -584,6 +621,7 @@ $strPrivilegesReloaded = 'Privilegije su uspješno učitane.';
 $strProcedures = 'Postupci';
 $strProcesses = 'Procesi';
 $strProcesslist = 'Popis procesa';
+$strProfiling = 'Izrada profila';
 $strProtocolVersion = 'Verzija protokola';
 $strPutColNames = 'Nazive polja stavi u prvi red';
 
@@ -602,15 +640,18 @@ $strQueryWindowLock = 'Ne prepisuj ovaj upit iz vanjskog prozora';
 
 $strReadRequests = 'Pročitaj zahtjeve';
 $strReceived = 'Primljeno';
+$strRecommended = 'preporučeno';
 $strRecords = 'Zapisi';
 $strReferentialIntegrity = 'Provjeri referencijalan integritet:';
 $strRefresh = 'Osvježi';
 $strRelationalSchema = 'Shema relacija';
+$strRelationDeleted = 'Povezanost je izbrisana';
 $strRelationNotWorking = 'Dodatne osobine za rad s povezanim tablicama su isključene. Da biste saznali zašto kliknite %sovdje%s.';
 $strRelationsForTable = 'RELACIJE TABLICE';
 $strRelations = 'Relacije';
 $strRelationView = 'Prikaz relacija';
 $strReloadingThePrivileges = 'Ponovno učitavanje privilegija';
+$strReload = 'Osvježi';
 $strReloadPrivileges = 'Ponovno učitaj privilegije';
 $strRemoveSelectedUsers = 'Ukloni odabrane korisnike';
 $strRenameDatabaseOK = 'Baza podataka %s preimenovana je u %s';
@@ -622,12 +663,15 @@ $strReplaceTable = 'Podatke tablice zamijeni datotekom';
 $strReplication = 'Replikacija';
 $strReset = 'Povrat';
 $strResourceLimits = 'Ograničenja resursa';
+$strRestartInsertion = 'Ponovno pokreni umetanje s %s redaka';
 $strReType = 'Ponovite';
 $strRevokeAndDeleteDescr = 'Korisnici će i dalje imati privilegiju USAGE (Upotreba) sve dok se privilegije ponovno ne učitaju.';
 $strRevokeAndDelete = 'Opozovi sve aktivne privilegije korisnika i potom ih izbriši.';
 $strRevokeMessage = 'Opozvali ste privilegije za %s';
 $strRevoke = 'Opozovi';
 $strRomanian = 'Rumunjski';
+$strRoutineReturnType = 'Vrsta povratka';
+$strRoutines = 'Rutine';
 $strRowLength = 'Duljina retka';
 $strRowsFrom = 'redovi koji započinju zapisom #';
 $strRowSize = ' Veličina retka ';
@@ -644,6 +688,7 @@ $strRunSQLQuery = 'Pokreni SQL upit na bazi podataka %s';
 $strRussian = 'Ruski';
 
 $strSaveOnServer = 'Spremi na poslužitelju u mapi %s';
+$strSavePosition = 'Spremi položaj';
 $strSave = 'Spremi';
 $strScaleFactorSmall = 'Vrijednost omjera suviše je malen da bi shema stala na jednu stranicu';
 $strSearchFormTitle = 'Traži u bazi podataka';
@@ -661,7 +706,9 @@ $strSelectADb = 'Odaberite bazu podataka';
 $strSelectAll = 'Odaberi sve';
 $strSelectBinaryLog = 'Odaberite binarni zapisnik za prikaz';
 $strSelectFields = 'Odaberite polja (najmanje jedno):';
+$strSelectForeignKey = 'Odaberite strani ključ';
 $strSelectNumRows = 'unutar upita';
+$strSelectReferencedKey = 'Odaberite referentni ključ';
 $strSelectTables = 'Odaberite tablice';
 $strSend = 'Spremi kao datoteku';
 $strSent = 'Poslano';
@@ -676,6 +723,7 @@ $strServerTabVariables = 'Varijable';
 $strServerTrafficNotes = '<b>Promet poslužitelja</b>: Ove tablice prikazuju statistike mrežnog prometa na ovom MySQL poslužitelju od trenutka njegovog pokretanja.';
 $strServerVars = 'Varijable i postavke poslužitelja';
 $strServerVersion = 'Verzija poslužitelja';
+$strSessionStartupErrorGeneral = 'Pokretanje sesije nije moguće uslijed pogrešaka. Provjerite pogreške koje ispisuje vaš PHP i/ili datoteku zapisnika poslužitelja i pravilno konfigurirajte vašu instalaciju PHP-a.';
 $strSessionValue = 'Vrijednost sesije';
 $strSetEnumVal = 'Ako je vrata polja "enum" ili "set", unesite vrijednosti u sljedećem obliku: \'a\',\'B\',\'c\'...<br />Ako je potrebno unijeti lijevu kosu crtu ("\") or a single quote ("\'") amongst those values, precede it with a backslash (for example \'\\\\xyz\' or \'a\\\'b\').';
 $strShowAll = 'Prikaži sve';
@@ -683,8 +731,11 @@ $strShowColor = 'Prikaži boju';
 $strShowDatadictAs = 'Oblikovanje rječnika podataka';
 $strShowFullQueries = 'Prikaži pune upite';
 $strShowGrid = 'Prikaži mrežu';
+$strShowHideLeftMenu = 'Prikaži/sakrij lijevi izbornik';
 $strShowingBookmark = 'Prikazivanje oznake';
+$strShowingPhp = 'Prikazivanje kao PHP koda';
 $strShowingRecords = 'Prikazivanje redaka';
+$strShowingSQL = 'Prikazivanje SQL upita';
 $strShowOpenTables = 'Prikaži otvorene tablice';
 $strShowPHPInfo = 'Prikaži PHP podatke';
 $strShow = 'Prikaži';
@@ -806,6 +857,8 @@ $strSize = 'Veličina';
 $strSkipQueries = 'Broj zapisa (upita) koje je potrebno preskočiti od početka';
 $strSlovak = 'Slovački';
 $strSlovenian = 'Slovenski';
+$strSmallBigAll = 'Malo / Sve veliko';
+$strSnapToGrid = 'Poravnaj s mrežom';
 $strSocketProblem = '(ili priključak lokalnog MySQL poslužitelja nije ispravno konfiguriran)';
 $strSortByKey = 'Presloži po ključu';
 $strSorting = 'Preslagivanje';
@@ -823,6 +876,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Neispravna ID oznaka';
 $strSQPBugUnclosedQuote = 'Navodnik nije zatvoren';
 $strSQPBugUnknownPunctuation = 'Nepoznat niz interpunkcija';
+$strStandInStructureForView = 'Unutarnja struktura za pregledavanje';
 $strStatCheckTime = 'Posljednja provjera';
 $strStatCreateTime = 'Izrada';
 $strStatement = 'Izjave';
@@ -837,6 +891,7 @@ $strStrucExcelCSV = 'CSV za MS Excel';
 $strStrucNativeExcel = 'Izvorno MS Excel oblikovanje';
 $strStrucOnly = 'Samo strukturu';
 $strStructPropose = 'Predloži strukturu tablice';
+$strStructureForView = 'Struktura za pregledavanje';
 $strStructure = 'Strukturu';
 $strSubmit = 'Podnesi';
 $strSuccess = 'Vaš SQL upit uspješno je izvršen';
@@ -851,7 +906,9 @@ $strTableEmpty = 'Naziv tablice je prazan!';
 $strTableHasBeenDropped = 'Tablica %s je odbačen';
 $strTableHasBeenEmptied = 'Tablica %s je očišćena';
 $strTableHasBeenFlushed = 'Tablica %s je ispražnjena';
+$strTableIsEmpty = 'Tablica izgleda praznom!';
 $strTableMaintenance = 'Održavanje tablice';
+$strTableName = 'Naziv tablice';
 $strTableOfContents = 'Sadržaj tablice';
 $strTableOptions = 'Opcije tablice';
 $strTables = '%s tablica';
@@ -875,7 +932,10 @@ $strTimeoutInfo = 'Vrijeme prethodnog uvoza je isteklo. Nakon ponovno podnošenj
 $strTimeoutNothingParsed = 'Ipak, pri posljednjem prijelazu nikakvi podaci nisu bili raščlanjeni. To znači da phpMyAdmin neće biti u mogućnosti završiti ovaj uvoz sve dok ne povećate vremenska ograničenja unutar php.';
 $strTimeoutPassed = 'Vrijeme za skriptu je isteklo. Ako želite završiti uvoz, ponovo podnesite istu datoteku i uvoz će nastaviti.';
 $strTime = 'Vrijeme';
+$strToFromPage = 'stranica od / prema';
 $strToggleScratchboard = 'Uključi bilješke';
+$strToggleSmallBig = 'Malo / Veliko';
+$strToSelectRelation = 'Za odabir povezanosti kliknite:';
 $strTotalUC = 'Ukupno';
 $strTotal = 'ukupno';
 $strTraditionalChinese = 'Kineski, tradicionalan';
@@ -887,12 +947,14 @@ $strTransformation_application_octetstream__hex = 'Prikazuje podatke u heksadeci
 $strTransformation_image_jpeg__inline = 'Prikazuje sličicu s mogućnošću klikanja. Opcije su najveća širina i visina u pikselima. Izvorne proporcije su očuvane.';
 $strTransformation_image_jpeg__link = 'Prikazuje vezu za preuzimanje ove slike.';
 $strTransformation_image_png__inline = 'Pogledajte slika/jpeg: inline';
+$strTransformation_text_plain__dateformat = 'Polja TIME (vrijeme), TIMESTAMP (vremenska oznaka), DATETIME (datum i vrijeme) ili brojčanu uniksoidnu oznaku vremena prikazuje kao oblikovani datum. Prva opcija je odmak (u satima) koji će biti pridodan vremenskoj oznaci (zadano: 0). Druga opcije određuje drukčiji oblik izražavanja datuma i vremena. Treća opcija određuje želite li prikazati lokalni datum ili u skladu s UTC (upotrijebite izraz "local" ili "utc"). Sukladno tome, oblik datuma ima različite vrijednosti - za opciju "local" pogledajte dokumentaciju o upotrebi PHP funkcije strftime(), a za "utc" pogledajte dokumentaciju o upotrebi funkcije gmdate().';
 $strTransformation_text_plain__external = 'SAMO ZA LINUX: Pokreće vanjsku aplikaciju i predaje joj podatke polja putem standardnog unosa. Vraća standardan ispis aplikacije. Zadana aplikacija je Tidy, uredno ispisivanje HTML koda. Iz sigurnosnih razloga morate ručno urediti datoteku libraries/transformations/text_plain__external.inc.php i izraditi popis alata koje želite učiniti raspoloživim. Prva opcija će biti redni broj programa kojeg želite upotrebljavati a druga opcija su parametri programa. Ako je treća opcija postavljena na vrijednost 1, pretvorit će ispis pomoću htmlspecialchars(), (zadano: 1). Ako je četvrta opcija postavljena na vrijednost 1, spriječit će omatanje i osigurati prikaz ispisa u jednom retku (zadano: 1).';
 $strTransformation_text_plain__formatted = 'Prikazuje sadržaj polje u izvornom obliku, bez njegovog provlačenja kroz htmlspecialchars(). Odnosno, za polje se pretpostavlja da ne sadrži valjani HTML kod.';
 $strTransformation_text_plain__imagelink = 'Prikazuje sliku i vezu. Polje sadrži naziv datoteke. Prva opcija je URL prefiks, poput "http://www.example.com/". Druga i treća opcija predstavljaju širinu i visinu u pikselima.';
 $strTransformation_text_plain__link = 'Prikazuje vezu. Polje sadrži naziv datoteke. Prva opcija je URL prefiks, poput "http://www.example.com/". Druga opcija je naziv veze.';
 $strTransformation_text_plain__sql = 'Oblikuje tekst kao SQL upit s naglašavanjem sintakse.';
 $strTransformation_text_plain__substr = 'Prikazuje dio niza. Prva opcija je broj znakova koje je potrebno preskočiti, od početka niza (zadano: 0). Druga opcija je broj znakova za povrat (zadano: do završetka niza). Treća opcija  je niz koji je potrebno pridodati iza završetka i/ili prije početka kad započne srezivanje (zadano: "...").';
+$strTriggers = 'Okidači';
 $strTruncateQueries = 'Sreži prikazane rezultate';
 $strTurkish = 'Turski';
 $strType = 'Vrsta';
@@ -909,6 +971,13 @@ $strUpdateProfileMessage = 'Profil je ažuriran.';
 $strUpdateQuery = 'Ažuriraj upit';
 $strUpdComTab = 'Pogledajte dokumentaciju radi uputa o ažuriranju tablice column_comments.';
 $strUpgrade = 'Trebali biste nadograditi na %s %s ili kasniju.';
+$strUploadErrorCantWrite = 'Zapisivanje datoteke na disk nije uspjelo.';
+$strUploadErrorExtension = 'Učitavanje datoteke prekinuto je uslijed ekstenzije.';
+$strUploadErrorFormSize = 'Učitana datoteka nadmašuje uputu MAX_FILE_SIZE (najveća veličina datoteke), određenu u HTML obliku.';
+$strUploadErrorIniSize = 'Učitana datoteka nadmašuje uputu upload_max_filesize (najveća veličina datoteke) u datoteci php.ini.';
+$strUploadErrorNoTempDir = 'Nedostaje mapa privremene pohrane.';
+$strUploadErrorPartial = 'Učitana datoteka bila je djelomično učitana.';
+$strUploadErrorUnknown = 'Nepoznata pogreška tijekom učitavanja datoteke.';
 $strUploadLimit = 'Vjerojatno ste pokušali s učitavanjem prevelike datoteke. Pogledajte %sdokumentaciju%s radi uputa o načinima rješavanja ovog ograničenja.';
 $strUploadsNotAllowed = 'Učitavanje datoteka nije dopušteno na ovom poslužitelju.';
 $strUsage = 'Upotreba';
@@ -938,6 +1007,7 @@ $strViewDumpDB = 'Prikaži ispis (shemu) baze podataka';
 $strViewDump = 'Prikaži ispis (shemu) tablice';
 $strViewHasBeenDropped = 'Index %s je ispušten';
 $strViewMaxExactCount = 'Ovaj prikaz sadrži više od %s redaka. Pogledajte %sdokumentaciju%s.';
+$strViewName = 'Naziv prikaza';
 $strView = 'Prikaz';
 
 $strWebServerUploadDirectoryError = 'Mapu koju ste odabrali za potrebe učitavanja nije moguće dohvatiti';
@@ -957,73 +1027,5 @@ $strYes = 'Da';
 $strZeroRemovesTheLimit = 'Napomena: Postavljanje ovih opcija na vrijednost 0 (nula) uklanja ograničenje.';
 $strZip = '"zipano"';
 
-$strPmaWiki = 'phpMyAdmin wiki';  //to translate
-$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
-$strDocSQL = 'DocSQL';  //to translate
-$strTableName = 'Table name';  //to translate
-$strTableIsEmpty = 'Table seems to be empty!';  //to translate
-$strDbIsEmpty = 'Database seems to be empty!';  //to translate
-$strShowingPhp = 'Showing as PHP code';  //to translate
-$strShowingSQL = 'Showing SQL query';  //to translate
-$strDesigner = 'Designer';  //to translate
-$strNumberOfTables = 'Number of tables';  //to translate
-$strCreateTable  = 'Create table';  //to translate
-$strCreateRelation = 'Create relation';  //to translate
-$strSavePosition = 'Save position';  //to translate
-$strSelectForeignKey = 'Select Foreign Key';  //to translate
-$strHide         = 'Hide';  //to translate
-$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
-$strReload = 'Reload';  //to translate
-$strSmallBigAll = 'Small/Big All';  //to translate
-$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
-$strMoveMenu = 'Move Menu';  //to translate
-$strAngularLinks = 'Angular links';  //to translate
-$strDirectLinks = 'Direct links';  //to translate
-$strHideShowAll = 'Hide/Show all';  //to translate
-$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
-$strInternalRelationAdded = 'Internal relation added';  //to translate
-$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
-$strRelationDeleted = 'Relation deleted';  //to translate
-$strToSelectRelation = 'To select relation, click :';  //to translate
-$strExportImportToScale = 'Export/Import to scale';  //to translate
-$strRecommended = 'recommended';  //to translate
-$strToFromPage = 'to/from page';  //to translate
-$strSelectReferencedKey = 'Select referenced key';  //to translate
-$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
-$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
-$strHelp = 'Help';  //to translate
-$strCancel = 'Cancel';  //to translate
-$strDeleteRelation = 'Delete relation';  //to translate
-$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
-$strStructureForView = 'Structure for view';  //to translate
-$strStandInStructureForView = 'Stand-in structure for view';  //to translate
-$strToggleSmallBig = 'Toggle small/big';  //to translate
-$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
-$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
-$strErrorRelationExists = 'Error: relation already exists.';  //to translate
-$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
-$strSnapToGrid = 'Snap to grid';  //to translate
-$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
-$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
-$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
-$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
-$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
-$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
-$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
-$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
-$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
-$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
-$strViewName = 'VIEW name';  //to translate
-$strOptions = 'Options';  //to translate
-$strFiles = 'Files';  //to translate
-$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
-$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
-$strRoutines = 'Routines';  //to translate
-$strRoutineReturnType = 'Return type';  //to translate
-$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
-$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
-$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
-$strTriggers = 'Triggers';  //to translate
-$strEvent = 'Event';  //to translate
-$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
