@@ -1,7 +1,7 @@
 <?php
-/* $Id: english-iso-8859-15.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
+/* $Id: english-iso-8859-1.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
-$charset = 'iso-8859-15';
+$charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
@@ -50,7 +50,7 @@ $strAfterInsertNext = 'Edit next row';
 $strAfterInsertSame = 'Go back to this page';
 $strAll = 'All';
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';
-$strAllTableSameWidth = 'display all tables with same width?';
+$strAllTableSameWidth = 'Display all tables with the same width';
 $strAlterOrderBy = 'Alter table order by';
 $strAnalyzeTable = 'Analyze table';
 $strAnd = 'And';
@@ -894,6 +894,7 @@ $strStructureForView = 'Structure for view';
 $strStructure = 'Structure';
 $strSubmit = 'Submit';
 $strSuccess = 'Your SQL query has been executed successfully';
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';
 $strSum = 'Sum';
 $strSwedish = 'Swedish';
 $strSwitchToDatabase = 'Switch to copied database';
