@@ -1,10 +1,10 @@
 <?php
-/* $Id: french-utf-8.inc.php 10018 2007-02-26 17:26:53Z lem9 $ */
+/* $Id: french-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = ' ';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('o', 'Kio', 'Mio', 'Gio', 'Tio', 'Pio', 'Eio');
@@ -22,7 +22,7 @@ $timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';
 $strAbortedClients = 'Arrêts prématurés';
 $strAccessDenied = 'Accès refusé';
 $strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas créé de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
-$strAccessDeniedExplanation = 'phpMyAdmin a tenté de se connecter au serveur MySQL, et le serveur a rejeté la connexion. Veuillez vérifier les valeurs de "host", "username" et "password" dans config.inc.php et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
+$strAccessDeniedExplanation = 'phpMyAdmin a tenté de se connecter au serveur MySQL, et le serveur a rejeté la connexion. Veuillez vérifier les valeurs de "host", "username" et "password" dans votre configuration et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
 $strAddClause = 'Ajouter %s';
@@ -36,7 +36,7 @@ $strAddNewField = 'Ajouter un champ';
 $strAddPrivilegesOnDb = 'Ajouter des privilèges sur cette base de données';
 $strAddPrivilegesOnTbl = 'Ajouter des privilèges sur cette table';
 $strAddSearchConditions = 'Critères de recherche (pour l\'énoncé "where"):';
-$strAddToIndex = 'Ajouter à la clef&nbsp;%s&nbsp;colonne(s)';
+$strAddToIndex = 'Ajouter à l\'index&nbsp;%s&nbsp;colonne(s)';
 $strAddUser = 'Ajouter un utilisateur';
 $strAddUserMessage = 'Vous avez ajouté un utilisateur';
 $strAdministration = 'Administration';
@@ -66,7 +66,6 @@ $strAscending = 'Croissant';
 $strAtBeginningOfTable = 'En début de table';
 $strAtEndOfTable = 'En fin de table';
 $strAttr = 'Attributs';
-$strAutodetect = 'Détection automatique';
 $strAutomaticLayout = 'Mise en page automatique';
 
 $strBack = 'Retour';
@@ -112,7 +111,7 @@ $strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation
 $strCannotLogin = 'Connexion au serveur MySQL non permise';
 $strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vérifier votre configuration de PHP';
 $strCantLoadRecodeIconv = 'Erreur lors du chargement de l\'extension iconv ou recode, utilisée pour convertir le jeu de caractères; veuillez activer l\'une de ces extensions dans PHP, ou désactiver la conversion des jeux de caractères dans phpMyAdmin';
-$strCantRenameIdxToPrimary = 'La clef ne peut être renommée PRIMARY&nbsp;!';
+$strCantRenameIdxToPrimary = 'L\'index ne peut être renommé PRIMARY!';
 $strCantUseRecodeIconv = 'Erreur lors de l\'utilisation de iconv, libiconv et recode_string, alors que ces extensions semblent chargées. Veuillez vérifier votre configuration de PHP.';
 $strCardinality = 'Cardinalité';
 $strCaseInsensitive = 'insensible à la casse';
@@ -155,6 +154,7 @@ $strConnectionError = 'Connexion impossible: réglages incorrects.';
 $strConnections = 'Connexions';
 $strConstraintsForDumped = 'Contraintes pour les tables exportées';
 $strConstraintsForTable = 'Contraintes pour la table';
+$strControluserFailed = 'La connexion au "controluser" tel que défini dans votre configuration a échoué.';
 $strCookiesRequired = 'Vous devez accepter les cookies pour poursuivre.';
 $strCopy = 'Copier';
 $strCopyDatabaseOK = 'La base de données %s a été copiée sur %s';
@@ -164,8 +164,8 @@ $strCopyTableSameNames = 'On ne peut copier la table sur elle-même!';
 $strCouldNotKill = 'phpMyAdmin n\'a pu éliminer le processus %s. Il était probablement déjà fermé.';
 $strCreate = 'Créer';
 $strCreateDatabaseBeforeCopying = 'Faire CREATE DATABASE avant la copie';
-$strCreateIndex = 'Créer une clef sur&nbsp;%s&nbsp;colonne(s)';
-$strCreateIndexTopic = 'Créer un nouvelle clef';
+$strCreateIndex = 'Créer un index sur&nbsp;%s&nbsp;colonne(s)';
+$strCreateIndexTopic = 'Créer un nouvel index';
 $strCreateNewDatabase = 'Créer une base de données';
 $strCreateNewTable = '<b>Créer une nouvelle table</b> sur la base %s';
 $strCreatePage = 'Créer une page';
@@ -180,8 +180,6 @@ $strCreationDates = 'Dates de création/modification/vérification';
 $strCriteria = 'Critère';
 $strCroatian = 'croate';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Options CSV';
-$strCSVOptions = 'Options CSV';
 $strCyrillic = 'cyrillique';
 $strCzechSlovak = 'tchèque-slovaque';
 $strCzech = 'tchèque';
@@ -191,7 +189,6 @@ $strDatabase = 'Base de données';
 $strDatabaseEmpty = 'Le nom de la base de données est vide!';
 $strDatabaseExportOptions = 'Options d\'exportation';
 $strDatabaseHasBeenDropped = 'La base de données %s a été effacée.';
-$strDatabaseNoTable = 'Cette base de données ne contient aucune table!';
 $strDatabases = 'Bases de données';
 $strDatabasesDropped = '%s bases de données ont été supprimées.';
 $strDatabasesStatsDisable = 'Désactiver les statistiques';
@@ -237,7 +234,6 @@ $strDisplayOrder = 'Ordre d\'affichage :';
 $strDisplayPDF = '<b>Afficher le schéma</b> en PDF';
 $strDoAQuery = 'Recherche par valeur (passepartout: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'Options DocSQL';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Voulez-vous vraiment effectuer ';
 $strDropDatabaseStrongWarning = 'Vous êtes sur le point de DÉTRUIRE une base de données!';
@@ -274,8 +270,8 @@ $strErrorSaveTable = 'Erreur lors de la sauvegarde des coordonnées Concepteur.'
 $strEscapeWildcards = 'Préfixer avec \ les passepartouts _ et % pour un usage littéral';
 $strEsperanto = 'Espéranto';
 $strEstonian = 'estonien';
+$strEvent = 'Événement';
 $strExcelEdition = 'Excel en version';
-$strExcelOptions = 'Options Excel';
 $strExecuteBookmarked = 'Exécuter la requête en signets';
 $strExplain = 'Expliquer SQL';
 $strExport = 'Exporter';
@@ -287,8 +283,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Tentatives échouées';
 $strField = 'Champ';
 $strFieldHasBeenDropped = 'Le champ %s a été effacé';
+$strFieldInsertFromFileTempDirNotExists = 'Erreur lors du déplacement du fichier téléchargé, voir FAQ 1.11';
 $strFields = 'Champs';
-$strFieldsEmpty = 'Il faut indiquer le nombre de champs';
 $strFieldsEnclosedBy = 'Champs entourés par';
 $strFieldsEscapedBy = 'Caractère spécial';
 $strFieldsTerminatedBy = 'Champs terminés par';
@@ -300,6 +296,7 @@ $strFileNameTemplateDescriptionServer = 'nom de serveur';
 $strFileNameTemplateDescriptionTable = 'nom de table';
 $strFileNameTemplate = 'Modèle de nom de fichier';
 $strFileNameTemplateRemember = 'se souvenir du modèle';
+$strFiles = 'Fichiers';
 $strFileToImport = 'Fichier à importer';
 $strFixed = 'fixe';
 $strFlushPrivilegesNote = 'Note: phpMyAdmin obtient la liste des privilèges directement à partir des tables MySQL. Le contenu de ces tables peut être différent des privilèges effectifs, si des changements manuels ont été apportés. Dans ce cas, vous devriez %srecharger les privilèges%s avant de continuer.';
@@ -336,7 +333,7 @@ $strHasBeenCreated = 'a été créé(e).';
 $strHaveToShow = 'Vous devez choisir au moins une colonne à afficher';
 $strHebrew = 'hébreu';
 $strHelp = 'Aide';
-$strHexForBinary = 'Encoder les champs binaires en hexadécimal';
+$strHexForBLOB = 'Utiliser l\'hexadecimal pour les BLOB';
 $strHide         = 'Cacher';
 $strHideShowAll = 'Cacher/montrer tout';
 $strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
@@ -345,9 +342,7 @@ $strHomepageOfficial = 'Site officiel de phpMyAdmin';
 $strHostEmpty = 'Le nom de serveur est vide';
 $strHost = 'Serveur';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Options d\'exportation Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Options d\'exportation Microsoft Word 2000';
 $strHungarian = 'hongrois';
 
 $strIcelandic = 'islandais';
@@ -363,14 +358,12 @@ $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
 $strImportSuccessfullyFinished = 'L\'importation s\'est terminée avec succès, %d requêtes exécutées.';
 $strIndexes = 'Index';
+$strIndexesSeemEqual = 'Les index suivants semblent équivalents, vous devriez en éliminer un.';
 $strIndexHasBeenDropped = 'L\'index %s a été effacé';
 $strIndex = 'Index';
-$strIndexName = 'Nom de la clef&nbsp;:';
-$strIndexType = 'Type de clef&nbsp;:';
-$strIndexWarningMultiple = 'Plus d\'un index de type %s existe pour la colonne `%s`';
-$strIndexWarningPrimary = 'La colonne `%s` ne devrait pas faire partie à la fois d\'une clé primaire et d\'une clé index';
+$strIndexName = 'Nom de l\'index&nbsp;:';
+$strIndexType = 'Type d\'index&nbsp;:';
 $strIndexWarningTable = 'Il y a des problèmes avec les index de la table `%s`';
-$strIndexWarningUnique = 'La colonne `%s` ne devrait pas faire partie à la fois d\'une clé unique et d\'une clé index';
 $strInnoDBAutoextendIncrement = 'Auto-croissant: Taille de l\'incrément';
 $strInnoDBAutoextendIncrementDesc = 'La valeur de l\'incrément lors de l\'agrandissement du fichier auto-croissant lorsqu\'il devient plein.';
 $strInnoDBBufferPoolSizeDesc = 'La taille de la mémoire-tampon utilisée par InnoDB pour les opérations d\'antémoire sur les données et les index.';
@@ -413,13 +406,12 @@ $strJustDelete = 'Seulement effacer les utilisateurs des tables de privilèges.'
 
 $strKeepPass = 'Conserver le mot de passe';
 $strKeyCache = 'Cache des clés';
-$strKeyname = 'Nom de la clé';
+$strKeyname = 'Nom de l\'index';
 $strKill = 'Supprimer';
 $strKnownExternalBug = 'La fonctionnalité %s est affectée par une anomalie connue, voir %s';
 $strKorean = 'coréen';
 
 $strLandscape = 'Paysage';
-$strLanguageFileNotFound = 'Fichier de langue "%1$s" inexistant.';
 $strLanguage = 'Langue';
 $strLanguageUnknown = 'Langue inconnue: %1$s.';
 $strLatchedPages = 'Pages verrouillées';
@@ -430,11 +422,9 @@ $strLatexContinued = '(suite)';
 $strLatexIncludeCaption = 'Inclure les sous-titres';
 $strLatexLabel = 'Clé de l\'étiquette';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Options LaTeX';
 $strLatexStructure = 'Structure de la table __TABLE__';
 $strLatvian = 'letton';
 $strLDI = 'CSV via LOAD DATA';
-$strLDIImportOptions = 'Options pour l\'importation CSV via LOAD DATA';
 $strLDILocal = 'Utiliser l\'option LOCAL';
 $strLengthSet = 'Taille/Valeurs*';
 $strLimitNumRows = 'Nombre d\'enregistrements par page';
@@ -469,7 +459,7 @@ $strMIME_transformation = 'Transformation';
 $strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
 $strMIME_without = 'Les types MIME affichées en italiques ne possèdent pas de fonctions de transformation.';
 $strModifications = 'Les modifications ont été sauvegardées.';
-$strModifyIndexTopic = 'Modifier une clef';
+$strModifyIndexTopic = 'Modifier un index';
 $strModify = 'Modifier';
 $strMoveMenu = 'Déplacer le menu';
 $strMoveTable = '<b>Déplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
@@ -491,6 +481,7 @@ $strMyISAMSortBufferSize = 'Taille de la mémoire tampon';
 $strMySQLCharset = 'Jeu de caractères pour MySQL';
 $strMysqlClientVersion = 'Version du client MySQL';
 $strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
+$strMysqlLibDiffersServerVersion = 'La version de votre bibliothèque MySQL (%s) diffère de la version de votre serveur MySQL (%s). Ceci peut occasionner un comportement imprévisible.';
 $strMySQLSaid = 'MySQL a répondu:';
 $strMySQLShowProcess = 'Afficher les processus';
 $strMySQLShowStatus = 'Afficher l\'état du serveur';
@@ -508,8 +499,8 @@ $strNoDropDatabases = 'La commande "DROP DATABASE" est désactivée.';
 $strNoExplain = 'Ne pas expliquer SQL';
 $strNoFilesFoundInZip = 'Aucun fichier présent dans l\'archive ZIP!';
 $strNoFrames = 'L\'utilisation de phpMyAdmin est plus aisée avec un navigateur <b>supportant les "frames"</b>.';
-$strNoIndex = 'Aucune clef n\'est définie&nbsp;!';
-$strNoIndexPartsDefined = 'Aucune colonne n\'a été définie pour cette clef&nbsp;!';
+$strNoIndex = 'Aucun index n\'est défini&nbsp;!';
+$strNoIndexPartsDefined = 'Aucune colonne n\'a été définie pour cet index&nbsp;!';
 $strNoModification = 'Pas de modifications';
 $strNone = 'aucune';
 $strNo = 'Non';
@@ -536,14 +527,13 @@ $strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Options pour tableur "Open Document"';
 $strOpenDocumentSpreadsheet = 'Tableur "Open Document"';
-$strOpenDocumentTextOptions = 'Options pour texte "Open Document"';
 $strOpenDocumentText = 'Texte "Open Document"';
 $strOpenNewWindow = 'Ouvrir une nouvelle fenêtre phpMyAdmin';
 $strOperations = 'Opérations';
 $strOperator = 'Opérateur';
 $strOptimizeTable = 'Optimiser la table';
+$strOptions = 'Options';
 $strOr = 'Ou';
 $strOverhead = 'Perte';
 $strOverwriteExisting = 'Écraser les fichiers existants';
@@ -561,7 +551,6 @@ $strPasswordNotSame = 'Les mots de passe doivent être identiques';
 $strPdfDbSchema = 'Schema de la base "%s" - Page %s';
 $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
-$strPDFOptions = 'Options PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Génère un rapport contenant les données d\'une seule table)';
 $strPDFReportTitle = 'Titre du rapport';
@@ -573,7 +562,7 @@ $strPhoneBook = 'annuaire téléphonique';
 $strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un sérieux problème avec les caractères multi-octets (mbstring), tel que décrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommandé d\'utiliser cette version de PHP avec phpMyAdmin.';
 $strPhp = 'Créer source PHP';
 $strPHPVersion = 'Version de PHP';
-$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la clé primaire ou une clé unique';
+$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la clé primaire ou un index unique';
 $strPmaDocumentation = 'Documentation de phpMyAdmin';
 $strPmaUriError = 'Le paramètre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT être renseigné dans votre fichier de configuration !';
 $strPmaWiki = 'Wiki phpMyAdmin';
@@ -582,8 +571,8 @@ $strPortrait = 'Portrait';
 $strPos1 = 'Début';
 $strPrevious = 'Précédent';
 $strPrimaryKeyHasBeenDropped = 'La clé primaire a été effacée';
-$strPrimaryKeyName = 'Le nom d\'une clef primaire doit être PRIMARY&nbsp;!';
-$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut être</b> que le nom d\'une clef primaire&nbsp;!)';
+$strPrimaryKeyName = 'Le nom d\'une clé primaire doit être PRIMARY!';
+$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut être</b> que le nom d\'une clé primaire&nbsp;!)';
 $strPrimary = 'Primaire';
 $strPrint = 'Imprimer';
 $strPrintViewFull = 'Version imprimable (avec textes complets)';
@@ -629,6 +618,7 @@ $strPrivilegesReloaded = 'Les privilèges ont été rechargés.';
 $strProcedures = 'Procédures';
 $strProcesses = 'Processus';
 $strProcesslist = 'Liste des processus';
+$strProfiling = 'Profilage';
 $strProtocolVersion = 'Version du protocole';
 $strPutColNames = 'Afficher les noms de champ en première ligne';
 
@@ -641,7 +631,7 @@ $strQueryOnDb = 'Requête SQL sur la base <b>%s</b>&nbsp;:';
 $strQueryResultsOperations = 'Opérations sur les résultats de la requête';
 $strQuerySQLHistory = 'Historique SQL';
 $strQueryStatistics = '<b>Statistiques sur les requêtes</b>: Depuis son démarrage, %s requêtes ont été envoyées au serveur.';
-$strQueryTime = 'traitement: %01.4f sec.';
+$strQueryTime = 'Traitement en %01.4f sec.';
 $strQueryType = 'Type de requête';
 $strQueryWindowLock = 'Ne pas écraser cette requête depuis une autre fenêtre';
 
@@ -670,12 +660,15 @@ $strReplaceTable = 'Remplacer les données de la table avec le fichier';
 $strReplication = 'Réplication';
 $strReset = 'Réinitialiser les valeurs';
 $strResourceLimits = 'Limites de ressources.';
+$strRestartInsertion = 'Recommencer l\'insertion avec %s lignes';
 $strReType = 'Entrer à nouveau';
 $strRevokeAndDeleteDescr = 'Les utilisateurs auront le privilege "USAGE", jusqu\'à ce que les privilèges soient rechargés.';
 $strRevokeAndDelete = 'Effacer tous les privilèges de ces utilisateurs, puis les effacer.';
 $strRevokeMessage = 'Vous avez révoqué les privilèges pour %s';
 $strRevoke = 'Révoquer';
 $strRomanian = 'roumain';
+$strRoutineReturnType = 'Type retourné';
+$strRoutines = 'Procédures stockées';
 $strRowLength = 'Longueur enr.';
 $strRows = 'Enregistrements';
 $strRowsFrom = 'enregistrement(s) à partir de l\'enregistrement n°';
@@ -727,6 +720,7 @@ $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Statistiques sur le trafic</b>: Ce tableau indique le trafic réseau observé sur ce serveur MySQL depuis son démarrage.';
 $strServerVars = 'Variables et réglages du serveur';
 $strServerVersion = 'Version du serveur';
+$strSessionStartupErrorGeneral = 'Erreur lors du démarrage de la session, veuillez vérifier les erreurs indiquées par PHP ou dans le fichier témoin du serveur web, et configurer PHP correctement.';
 $strSessionValue = 'Valeur pour la session';
 $strSetEnumVal = 'Les différentes valeurs des champs de type enum/set sont à spécifier sous la forme \'a\',\'b\',\'c\'...<br />Pour utiliser un caractère "\\" ou "\'" dans l\'une de ces valeurs, faites-le précéder du caractère d\'échappement "\\" (par exemple \'\\\\xyz\' ou \'a\\\'b\').';
 $strShow = 'Afficher';
@@ -816,7 +810,7 @@ $strShowStatusKey_readsDescr = 'Le nombre de lectures physiques d\'un bloc de cl
 $strShowStatusKey_write_requestsDescr = 'Le nombre de requêtes en vue d\'écrire un bloc de clé dans la cache.';
 $strShowStatusKey_writesDescr = 'Le nombre d\'écritures physiques d\'un bloc de clés vers le disque.';
 $strShowStatusLast_query_costDescr = 'Le coût total de la dernière requête compilée, tel que calculé par l\'optimiseur de requêtes. Utile pour comparer le coût de diverses stratégies pour une même requête. La valeur de 0 indique qu\'aucune requête n\'a encore été compilée.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'écriture (INSERT DELAY).';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'écriture (INSERT DELAYED).';
 $strShowStatusOpened_tablesDescr = 'Le nombre tables qui ont été ouvertes. Si trop élevé, votre cache de table est probablement trop petite.';
 $strShowStatusOpen_filesDescr = 'Le nombre de fichiers qui sont ouverts.';
 $strShowStatusOpen_streamsDescr = 'Le nombre de flux de données qui sont ouverts.';
@@ -871,8 +865,6 @@ $strSpanish = 'espagnol';
 $strSplitWordsWithSpace = 'Séparer les mots par un espace (" ").';
 $strSQLCompatibility = 'Mode de compatibilité SQL';
 $strSQLExportType = 'Type d\'exportation';
-$strSQLImportOptions = 'Options SQL';
-$strSQLOptions = 'options SQL';
 $strSQLParserBugMessage = 'Il semble que vous ayiez trouvé une anomalie dans l\'analyseur syntaxique SQL. Veuillez examiner votre requête attentivement, et vérifier que vos apostrophes sont conformes. Il se pourrait aussi que vous ayiez chargé un fichier dont le contenu binaire n\'est pas entre apostrophes.  Si vous avez accès à MySQL via son interface de commande en mode ligne, vous pouvez y essayer votre requête. Le message d\'erreur présenté plus bas pourrait vous indiquer la source du problème. En dernier recours, veuillez trouver la plus courte requête possible qui cause le problème, et soumettre un rapport d\'anomalie en incluant la section à couper:';
 $strSQLParserUserError = 'Il semble qu\'il y ait une erreur dans votre requête SQL. Le message ci-bas peut vous aider à en trouver la cause.';
 $strSQLQuery = 'requête SQL';
@@ -894,7 +886,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Structure et données';
 $strStrucExcelCSV = 'CSV pour MS Excel';
 $strStrucNativeExcel = 'Données MS Excel (format natif)';
-$strStrucNativeExcelOptions = 'Options pour Excel natif';
 $strStrucOnly = 'Structure seule';
 $strStructPropose = 'Suggérer des optimisations quant à la structure de la table';
 $strStructureForView = 'Structure de la vue';
@@ -960,6 +951,7 @@ $strTransformation_text_plain__imagelink = 'Affiche une image et un lien, le cha
 $strTransformation_text_plain__link = 'Affiche un lien, le champ contient le nom du fichier; en première option, un préfixe comme "http://domaine.com/", en seconde option, un titre pour le lien.';
 $strTransformation_text_plain__sql = 'Affiche le texte comme une requête SQL avec embellissement de la syntaxe.';
 $strTransformation_text_plain__substr = 'N\'affiche qu\'une partie du champ. En première option, la position de départ (par défaut, 0). En seconde option, le nombre de caractères à afficher (par défaut, le reste). En troisième option, des caractères à afficher à la fin du texte (par défaut: "...").';
+$strTriggers = 'Déclencheurs';
 $strTruncateQueries = 'Afficher les requêtes tronquées';
 $strTurkish = 'turc';
 $strType = 'Type';
@@ -976,6 +968,13 @@ $strUpdateProfileMessage = 'Le profil a été modifié.';
 $strUpdateQuery = 'Mise-à-jour de la requête';
 $strUpdComTab = 'La documentation indique comment mettre à jour votre table Column_comments';
 $strUpgrade = 'Vous devriez utiliser %s en version %s ou plus récente.';
+$strUploadErrorCantWrite = 'Erreur lors de l\'écriture du fichier sur disque.';
+$strUploadErrorExtension = 'Téléchargement arrêté par l\'extension.';
+$strUploadErrorFormSize = 'La taille du fichier téléchargé dépasse la limite permise par la directive MAX_FILE_SIZE présente dans le formulaire HTML.';
+$strUploadErrorIniSize = 'La taille du fichier téléchargé dépasse la limite permise par la directive upload_max_filesize de php.ini.';
+$strUploadErrorNoTempDir = 'Répertoire temporaire manquant.';
+$strUploadErrorPartial = 'Le fichier n\'a été que partiellement téléchargé.';
+$strUploadErrorUnknown = 'Erreur inconnue durant le téléchargement.';
 $strUploadLimit = 'Vous avez probablement tenté de télécharger un fichier trop volumineux. Veuillez vous référer à la %sdocumentation%s pour des façons de contourner cette limite.';
 $strUploadsNotAllowed = 'Les téléchargements vers ce serveur ne sont pas permis.';
 $strUsage = 'Espace';
@@ -1005,6 +1004,7 @@ $strViewDumpDatabases = 'Schéma et/ou contenu des bases de données';
 $strViewDumpDB = 'Schéma et données de la base ';
 $strViewHasBeenDropped = 'La vue %s a été supprimée';
 $strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous référer à la %sdocumentation%s.';
+$strViewName = 'Nom de la vue';
 $strView = 'Vue';
 
 $strWebServerUploadDirectoryError = 'Le répertoire de transfert est inaccessible';
@@ -1017,7 +1017,6 @@ $strWithChecked = 'Pour la sélection :';
 $strWriteRequests = 'Requêtes d\'écriture';
 $strWrongUser = 'Erreur d\'utilisateur/mot de passe. Accès refusé';
 
-$strXMLOptions = 'Options XML';
 $strXML = 'XML';
 
 $strYes = 'Oui';
@@ -1025,4 +1024,5 @@ $strYes = 'Oui';
 $strZeroRemovesTheLimit = 'Note: Une valeur de 0 (zero) enlève la limite.';
 $strZip = '"zippé"';
 
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
