@@ -1,5 +1,5 @@
 <?php
-/* $Id: russian-windows-1251.inc.php 10500 2007-07-17 15:25:57Z lem9 $ */
+/* $Id: russian-windows-1251.inc.php 11161 2008-03-09 14:12:30Z lem9 $ */
 
 /**
  * Translated by Gosha Sakovich <gt2 at users.sourceforge.net>
@@ -159,7 +159,7 @@ $strConnections = '';
 $strConstraintsForDumped = '    ';
 $strConstraintsForTable = '   ';
 $strControluserFailed = '         controluser,        config.inc.php.';
-$strCookiesRequired = '     cookies, .';
+$strCookiesRequired = '     cookies .';
 $strCopy = '';
 $strCopyDatabaseOK = '  %s    %s';
 $strCopyTable = '   ( <b>.</b>):';
@@ -523,7 +523,7 @@ $strNotOK = ' ';
 $strNotSet = ' <b>%s</b>       %s';
 $strNoUsersFound = '  .';
 $strNoValidateSQL = '   SQL';
-$strNull = '';
+$strNull = 'Null';
 $strNumberOfFields = ' ';
 $strNumberOfTables = ' ';
 $strNumSearchResultsInTable = '%s ()   <i>%s</i>';
@@ -646,7 +646,7 @@ $strRecords = '';
 $strReferentialIntegrity = '  :';
 $strRefresh = '';
 $strRelationalSchema = 'C ';
-$strRelationDeleted = 'Relation deleted';
+$strRelationDeleted = ' ';
 $strRelationNotWorking = '       .     %s%s.';
 $strRelations = '';
 $strRelationsForTable = ' ';
@@ -828,7 +828,7 @@ $strShowStatusQcache_not_cachedDescr = ' ,              SQL_NO_CACHE.';
 $strShowStatusQcache_queries_in_cacheDescr = ' ,   .';
 $strShowStatusQcache_total_blocksDescr = '   ,    .';
 $strShowStatusReset = '';
-$strShowStatusRpl_statusDescr = '   (    ).';
+$strShowStatusRpl_statusDescr = '   (  ).';
 $strShowStatusSelect_full_joinDescr = ' -,    .      0,    .';
 $strShowStatusSelect_full_range_joinDescr = ' -,        ,    .';
 $strShowStatusSelect_range_checkDescr = ' -,            .      0,    .';
@@ -870,7 +870,7 @@ $strSplitWordsWithSpace = '   (" ").';
 $strSQL = 'SQL';
 $strSQLCompatibility = '  SQL';
 $strSQLExportType = ' ';
-$strSQLParserBugMessage = '  SQL-  .         .              .       MySQL.   ,     MySQL-,   .    ,        ,    ,        ,      CUT  :';
+$strSQLParserBugMessage = '  SQL-  .    ,       .       ,        .       MySQL.   ,     MySQL-,   .    ,        ,    ,        ,      CUT  :';
 $strSQLParserUserError = ', SQL-  .   ,     MySQL-,   .';
 $strSQLQuery = 'SQL-';
 $strSQLResult = ' SQL-';
@@ -896,6 +896,7 @@ $strStructureForView = '  ';
 $strStructure = '';
 $strSubmit = '';
 $strSuccess = 'SQL-   ';
+$strSuhosin = '    Suhosin.       %s%s.';
 $strSum = '';
 $strSwedish = '';
 $strSwitchToDatabase = '    ';
@@ -918,21 +919,21 @@ $strTableStructure = ' ';
 $strTakeIt = '';
 $strTblPrivileges = '   ';
 $strTempData = ' ';
-$strTextAreaLength = '-   ,<br />   ';
+$strTextAreaLength = '-   <br />   ';
 $strThai = '';
 $strTheme = ' / ';
 $strThemeDefaultNotFound = ' - %s  !';
 $strThemeNoPreviewAvailable = '  .';
 $strThemeNotFound = ' %s  !';
 $strThemeNoValidImgPath = '        %s!';
-$strThemePathNotFound = '   %s  !';
+$strThemePathNotFound = '    %s  !';
 $strThisHost = ' ';
 $strThreads = '';
 $strThreadSuccessfullyKilled = ' %s   .';
 $strTime = '';
 $strTimeoutInfo = '    -   ,        %d.';
 $strTimeoutNothingParsed = '   ,    .    ,  phpMyAdmin        ,        php-.';
-$strTimeoutPassed = '  ,     ,      ,         .';
+$strTimeoutPassed = '  .     ,      ,         .';
 $strToFromPage = '';
 $strToggleScratchboard = '';
 $strToggleSmallBig = ' ';
