@@ -8,13 +8,6 @@
  *
  * Order of sections for common.inc.php:
  *
- * the include of libraries/defines_mysql.lib.php must be after the connection
- * to db to get the MySql version
- *
- * the authentication libraries must be before the connection to db
- *
- * ... so the required order is:
- *
  * LABEL_variables_init
  *  - initialize some variables always needed
  * LABEL_parsing_config_file
@@ -28,10 +21,8 @@
  * - loading of an authentication library
  * - db connection
  * - authentication work
- * - load of the libraries/defines_mysql.lib.php library to get the MySQL
- *   release number
  *
- * @version $Id: common.inc.php 10519 2007-07-22 18:36:05Z lem9 $
+ * @version $Id: common.inc.php 11391 2008-07-15 14:40:42Z lem9 $
  */
 
 /**
@@ -61,6 +52,11 @@ if (version_compare(phpversion(), '6', 'lt')) {
     @ini_set('magic_quotes_runtime', false);
 }
 
+/**
+ * for verification in all procedural scripts under libraries
+ */
+define('PHPMYADMIN', true);
+
 /**
  * core functions
  */
@@ -138,10 +134,27 @@ foreach ($GLOBALS as $key => $dummy) {
         die('numeric key detected');
     }
 }
+unset($dummy);
+
+/**
+ * PATH_INFO could be compromised if set, so remove it from PHP_SELF
+ * and provide a clean PHP_SELF here
+ */
+$PMA_PHP_SELF = PMA_getenv('PHP_SELF');
+$_PATH_INFO = PMA_getenv('PATH_INFO');
+if (! empty($_PATH_INFO) && ! empty($PMA_PHP_SELF)) {
+    $path_info_pos = strrpos($PMA_PHP_SELF, $_PATH_INFO);
+    if ($path_info_pos + strlen($_PATH_INFO) === strlen($PMA_PHP_SELF)) {
+        $PMA_PHP_SELF = substr($PMA_PHP_SELF, 0, $path_info_pos);
+    }
+}
+$PMA_PHP_SELF = htmlspecialchars($PMA_PHP_SELF);
+
 
 /**
  * just to be sure there was no import (registering) before here
- * we empty the global space
+ * we empty the global space (but avoid unsetting $variables_list
+ * and $key in the foreach(), we still need them!)
  */
 $variables_whitelist = array (
     'GLOBALS',
@@ -153,6 +166,9 @@ $variables_whitelist = array (
     '_ENV',
     '_COOKIE',
     '_SESSION',
+    'PMA_PHP_SELF',
+    'variables_whitelist',
+    'key'
 );
 
 foreach (get_defined_vars() as $key => $value) {
@@ -171,15 +187,15 @@ unset($key, $value, $variables_whitelist);
  * <code>
  * <form ...>
  * ... main form elments ...
- * <intput type="hidden" name="subform[action1][id]" value="1" />
+ * <input type="hidden" name="subform[action1][id]" value="1" />
  * ... other subform data ...
- * <intput type="submit" name="usesubform[action1]" value="do action1" />
+ * <input type="submit" name="usesubform[action1]" value="do action1" />
  * ... other subforms ...
- * <intput type="hidden" name="subform[actionX][id]" value="X" />
+ * <input type="hidden" name="subform[actionX][id]" value="X" />
  * ... other subform data ...
- * <intput type="submit" name="usesubform[actionX]" value="do actionX" />
+ * <input type="submit" name="usesubform[actionX]" value="do actionX" />
  * ... main form elments ...
- * <intput type="submit" name="main_action" value="submit form" />
+ * <input type="submit" name="main_action" value="submit form" />
  * </form>
  * </code
  *
@@ -199,16 +215,25 @@ if (isset($_POST['usesubform'])) {
      * track this
      */
     if (isset($_POST['redirect'])
-      && $_POST['redirect'] != basename(PMA_getenv('PHP_SELF'))) {
+      && $_POST['redirect'] != basename($PMA_PHP_SELF)) {
         $__redirect = $_POST['redirect'];
         unset($_POST['redirect']);
     }
     unset($subform_id, $subform);
+} else {
+    // Note: here we overwrite $_REQUEST so that it does not contain cookies,
+    // because another application for the same domain could have set
+    // a cookie (with a compatible path) that overrides a variable 
+    // we expect from GET or POST.
+    // We'll refer to cookies explicitly with the $_COOKIE syntax.
+    $_REQUEST = array_merge($_GET, $_POST);
 }
 // end check if a subform is submitted
 
 // remove quotes added by php
-if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
+// (get_magic_quotes_gpc() is deprecated in PHP 5.3, but compare with 5.2.99
+// to be able to test with 5.3.0-dev)
+if (function_exists('get_magic_quotes_gpc') && -1 == version_compare(PHP_VERSION, '5.2.99') && get_magic_quotes_gpc()) {
     PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
     PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
     PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
@@ -373,7 +398,10 @@ if (! PMA_isValid($_REQUEST['token']) || $_SESSION[' PMA_token '] != $_REQUEST['
      *  List of parameters which are allowed from unsafe source
      */
     $allow_list = array(
-        'db', 'table', 'lang', 'server', 'convcharset', 'collation_connection', 'target',
+        /* needed for direct access, see FAQ 1.34
+         * also, server needed for cookie login screen (multi-server)
+         */
+        'server', 'db', 'table', 'target',
         /* Session ID */
         'phpMyAdmin',
         /* Cookie preferences */
@@ -449,26 +477,20 @@ $_REQUEST['js_frame'] = PMA_ifSetOr($_REQUEST['js_frame'], '');
 /******************************************************************************/
 /* parsing configuration file                         LABEL_parsing_config_file      */
 
-if (empty($_SESSION['PMA_Config'])) {
-    /**
-     * We really need this one!
-     */
-    if (! function_exists('preg_replace')) {
-        PMA_fatalError('strCantLoad', 'pcre');
-    }
-
-    /**
-     * @global PMA_Config $_SESSION['PMA_Config']
-     */
-    $_SESSION['PMA_Config'] = new PMA_Config('./config.inc.php');
-
-} elseif (version_compare(phpversion(), '5', 'lt')) {
-    /**
-     * @todo move all __wakeup() functionality into session.inc.php
-     */
-    $_SESSION['PMA_Config']->__wakeup();
+/**
+ * We really need this one!
+ */
+if (! function_exists('preg_replace')) {
+    PMA_fatalError('strCantLoad', 'pcre');
 }
 
+/**
+ * @global PMA_Config $_SESSION['PMA_Config']
+ * force reading of config file, because we removed sensitive values
+ * in the previous iteration
+ */
+$_SESSION['PMA_Config'] = new PMA_Config('./config.inc.php');
+
 if (!defined('PMA_MINIMUM_COMMON')) {
     $_SESSION['PMA_Config']->checkPmaAbsoluteUri();
 }
@@ -716,9 +738,6 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // Gets the authentication library that fits the $cfg['Server'] settings
         // and run authentication
 
-        // (for a quick check of path disclosure in auth/cookies:)
-        $coming_from_common = true;
-
         // to allow HTTP or http
         $cfg['Server']['auth_type'] = strtolower($cfg['Server']['auth_type']);
         if (! file_exists('./libraries/auth/' . $cfg['Server']['auth_type'] . '.auth.lib.php')) {
@@ -840,6 +859,14 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         require_once './libraries/List_Database.class.php';
         $PMA_List_Database = new PMA_List_Database($userlink, $controllink);
 
+        /**
+         * some resetting has to be done when switching servers
+         */
+        if (isset($_SESSION['userconf']['previous_server']) && $_SESSION['userconf']['previous_server'] != $GLOBALS['server']) {
+            unset($_SESSION['userconf']['navi_limit_offset']);
+        }
+        $_SESSION['userconf']['previous_server'] = $GLOBALS['server'];
+
     } // end server connecting
 
     /**
@@ -870,15 +897,20 @@ if (! defined('PMA_MINIMUM_COMMON')) {
      * (note: when $cfg['ServerDefault'] = 0, constant is not defined)
      */
 
-    if (defined('PMA_MYSQL_INT_VERSION') && PMA_MYSQL_INT_VERSION >= 50037 && isset($_REQUEST['profiling'])) {
-       $_SESSION['profiling'] = true;
+    if (PMA_profilingSupported() && isset($_REQUEST['profiling'])) {
+        $_SESSION['profiling'] = true;
     } elseif (isset($_REQUEST['profiling_form'])) {
-       // the checkbox was unchecked
-            unset($_SESSION['profiling']);
+        // the checkbox was unchecked
+        unset($_SESSION['profiling']);
     }
 
 } // end if !defined('PMA_MINIMUM_COMMON')
 
+// remove sensitive values from session
+$_SESSION['PMA_Config']->set('blowfish_secret', '');
+$_SESSION['PMA_Config']->set('Servers', '');
+$_SESSION['PMA_Config']->set('default_server', '');
+
 if (!empty($__redirect) && in_array($__redirect, $goto_whitelist)) {
     /**
      * include subform target page
