@@ -3,8 +3,11 @@
 /**
  * Common Option Constants For DBI Functions
  *
- * @version $Id: database_interface.lib.php 10462 2007-06-25 14:00:35Z lem9 $
+ * @version $Id: database_interface.lib.php 11326 2008-06-17 21:32:48Z lem9 $
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  *
@@ -186,7 +189,7 @@ function PMA_DBI_get_tables($database, $link = null)
 
 /**
  * returns array of all tables in given db or dbs
- * this function expects unqoted names:
+ * this function expects unquoted names:
  * RIGHT: my_database
  * WRONG: `my_database`
  * WRONG: my\_database
@@ -212,12 +215,13 @@ function PMA_DBI_get_tables($database, $link = null)
  * @param   string          $table          table
  * @param   boolean|string  $tbl_is_group   $table is a table group
  * @param   resource        $link           mysql link
+ * @param   integer         $limit_offset   zero-based offset for the count 
+ * @param   boolean|integer $limit_count    number of tables to return 
  * @return  array           list of tables in given db(s)
  */
 function PMA_DBI_get_tables_full($database, $table = false,
     $tbl_is_group = false, $link = null, $limit_offset = 0, $limit_count = false)
 {
-    // currently supported for MySQL >= 50002
     if (true === $limit_count) {
         $limit_count = $GLOBALS['cfg']['MaxTableList'];
     }
@@ -302,6 +306,10 @@ function PMA_DBI_get_tables_full($database, $table = false,
                     . PMA_backquote($each_database) . ';';
             }
             $each_tables = PMA_DBI_fetch_result($sql, 'Name', null, $link);
+            if ($limit_count) {
+                $each_tables = array_slice($each_tables, $limit_offset, $limit_count);
+            }
+
             foreach ($each_tables as $table_name => $each_table) {
                 if ('comment' === $tbl_is_group
                   && 0 === strpos($each_table['Comment'], $table))
@@ -728,7 +736,7 @@ function PMA_DBI_get_columns($database, $table, $full = false, $link = null)
     $fields = PMA_DBI_fetch_result(
         'SHOW ' . ($full ? 'FULL' : '') . ' COLUMNS
         FROM ' . PMA_backquote($database) . '.' . PMA_backquote($table),
-        'Fields', ($full ? null : 'Fields'), $link);
+        'Field', ($full ? null : 'Field'), $link);
     if (! is_array($fields) || count($fields) < 1) {
         return false;
     }
@@ -843,7 +851,8 @@ function PMA_DBI_postConnect($link, $is_controluser = false)
         }
 
         // and we remove the non-UTF-8 choices to avoid confusion
-        if (!defined('PMA_REMOVED_NON_UTF_8')) {
+        // (unless there is a forced language)
+        if (!defined('PMA_REMOVED_NON_UTF_8') && ! isset($GLOBALS['cfg']['Lang'])) {
             foreach ($GLOBALS['available_languages'] as $each_lang => $dummy) {
                 if (substr($each_lang, -5) != 'utf-8') {
                     unset($GLOBALS['available_languages'][$each_lang]);
@@ -1264,8 +1273,11 @@ function PMA_DBI_get_triggers($db, $table) {
     $result = array();
 
     // available in INFORMATION_SCHEMA since MySQL 5.0.10
+    // Note: in http://dev.mysql.com/doc/refman/5.0/en/faqs-triggers.html
+    // their example uses WHERE TRIGGER_SCHEMA='dbname' so let's use this
+    // instead of WHERE EVENT_OBJECT_SCHEMA='dbname'
     if (PMA_MYSQL_INT_VERSION >= 50010) {
-        $triggers = PMA_DBI_fetch_result("SELECT TRIGGER_SCHEMA, TRIGGER_NAME, EVENT_MANIPULATION, ACTION_TIMING, ACTION_STATEMENT, EVENT_OBJECT_SCHEMA, EVENT_OBJECT_TABLE FROM information_schema.TRIGGERS WHERE EVENT_OBJECT_SCHEMA= '" . PMA_sqlAddslashes($db,true) . "' and EVENT_OBJECT_TABLE = '" . PMA_sqlAddslashes($table, true) . "';");
+        $triggers = PMA_DBI_fetch_result("SELECT TRIGGER_SCHEMA, TRIGGER_NAME, EVENT_MANIPULATION, ACTION_TIMING, ACTION_STATEMENT, EVENT_OBJECT_SCHEMA, EVENT_OBJECT_TABLE FROM information_schema.TRIGGERS WHERE TRIGGER_SCHEMA= '" . PMA_sqlAddslashes($db,true) . "' and EVENT_OBJECT_TABLE = '" . PMA_sqlAddslashes($table, true) . "';");
 
         if ($triggers) {
             $delimiter = '//';
@@ -1276,7 +1288,7 @@ function PMA_DBI_get_triggers($db, $table) {
                 $one_result['event_manipulation'] = $trigger['EVENT_MANIPULATION'];
 
                 $one_result['full_trigger_name'] = PMA_backquote($trigger['TRIGGER_SCHEMA']) . '.' . PMA_backquote($trigger['TRIGGER_NAME']);
-                $one_result['drop'] = 'DROP TRIGGER ' . $one_result['full_trigger_name'];
+                $one_result['drop'] = 'DROP TRIGGER IF EXISTS ' . $one_result['full_trigger_name'];
                 $one_result['create'] = 'CREATE TRIGGER ' . $one_result['full_trigger_name'] . ' ' . $trigger['ACTION_TIMING']. ' ' . $trigger['EVENT_MANIPULATION'] . ' ON ' . PMA_backquote($trigger['EVENT_OBJECT_SCHEMA']) . '.' . PMA_backquote($trigger['EVENT_OBJECT_TABLE']) . "\n" . ' FOR EACH ROW ' . $trigger['ACTION_STATEMENT'] . "\n" . $delimiter . "\n";
 
                 $result[] = $one_result;
