@@ -3,8 +3,11 @@
 /**
  * Library that provides common import functions that are used by import plugins
  *
- * @version $Id: import.lib.php 10238 2007-04-01 09:26:14Z cybot_tm $
+ * @version $Id: import.lib.php 11326 2008-06-17 21:32:48Z lem9 $
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  * We need to know something about user
