@@ -3,8 +3,11 @@
 /**
  * SQL import plugin for phpMyAdmin
  *
- * @version $Id: sql.php 10466 2007-06-27 13:39:25Z lem9 $
+ * @version $Id: sql.php 11326 2008-06-17 21:32:48Z lem9 $
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  *
@@ -66,6 +69,11 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
     }
     // Current length of our buffer
     $len = strlen($buffer);
+    // prepare an uppercase copy of buffer for PHP < 5
+    // outside of the loop
+    if (PMA_PHP_INT_VERSION < 50000) {
+        $buffer_upper = strtoupper($buffer);
+    }
     // Grab some SQL queries out of it
      while ($i < $len) {
         $found_delimiter = false;
@@ -73,43 +81,53 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
         //while (($i < $len) && (strpos('\'";#-/', $buffer[$i]) === FALSE)) $i++;
         //if ($i == $len) break;
         $oi = $i;
-        $p1 = strpos($buffer, '\'', $i);
-        if ($p1 === FALSE) {
-            $p1 = 2147483647;
+        $big_value = 2147483647;
+        $first_quote = strpos($buffer, '\'', $i);
+        if ($first_quote === FALSE) {
+            $first_quote = $big_value;
         }
         $p2 = strpos($buffer, '"', $i);
         if ($p2 === FALSE) {
-            $p2 = 2147483647;
+            $p2 = $big_value;
         }
-        $p3 = strpos($buffer, $sql_delimiter, $i);
-        if ($p3 === FALSE) {
-            $p3 = 2147483647;
+        /**
+         * @todo it's a shortcoming to look for a delimiter that might be
+         *       inside quotes (or even double-quotes)
+         */
+        $first_sql_delimiter = strpos($buffer, $sql_delimiter, $i);
+        if ($first_sql_delimiter === FALSE) {
+            $first_sql_delimiter = $big_value;
         } else {
             $found_delimiter = true;
         }
         $p4 = strpos($buffer, '#', $i);
         if ($p4 === FALSE) {
-            $p4 = 2147483647;
+            $p4 = $big_value;
         }
         $p5 = strpos($buffer, '--', $i);
         if ($p5 === FALSE || $p5 >= ($len - 2) || $buffer[$p5 + 2] > ' ') {
-            $p5 = 2147483647;
+            $p5 = $big_value;
         }
         $p6 = strpos($buffer, '/*', $i);
         if ($p6 === FALSE) {
-            $p6 = 2147483647;
+            $p6 = $big_value;
         }
         $p7 = strpos($buffer, '`', $i);
         if ($p7 === FALSE) {
-            $p7 = 2147483647;
+            $p7 = $big_value;
+        }
+        // catch also "delimiter"
+        if (PMA_PHP_INT_VERSION >= 50000) {
+            $p8 = stripos($buffer, 'DELIMITER', $i);
+        } else {
+            $p8 = strpos($buffer_upper, 'DELIMITER', $i);
         }
-        $p8 = strpos($buffer, 'DELIMITER', $i);
         if ($p8 === FALSE || $p8 >= ($len - 11) || $buffer[$p8 + 9] > ' ') {
-            $p8 = 2147483647;
+            $p8 = $big_value;
         }
-        $i = min ($p1, $p2, $p3, $p4, $p5, $p6, $p7, $p8);
-        unset($p1, $p2, $p3, $p4, $p5, $p6, $p7, $p8);
-        if ($i == 2147483647) {
+        $i = min ($first_quote, $p2, $first_sql_delimiter, $p4, $p5, $p6, $p7, $p8);
+        unset($first_quote, $p2, $p4, $p5, $p6, $p7, $p8);
+        if ($i == $big_value) {
             $i = $oi;
             if (!$finished) {
                 break;
@@ -141,6 +159,7 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
                         $endq = TRUE;
                         $i = $len - 1;
                     }
+                    $found_delimiter = false;
                     break;
                 }
                 // Was not the quote escaped?
@@ -150,6 +169,10 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
                 $endq = (((($pos - 1) - $j) % 2) == 0);
                 // Skip the string
                 $i = $pos;
+
+                if ($first_sql_delimiter < $pos) {
+                    $found_delimiter = false;
+                }
             }
             if (!$endq) {
                 break;
@@ -217,7 +240,7 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
             }
         }
        // Change delimiter, if redefined, and skip it (don't send to server!)
-       if ((substr($buffer, $i, 9) == "DELIMITER") && ($buffer[$i + 9] <= ' ') && ($i<$len-11) && (!(strpos($buffer,"\n",$i+11)===FALSE))) {
+       if ((strtoupper(substr($buffer, $i, 9)) == "DELIMITER") && ($buffer[$i + 9] <= ' ') && ($i<$len-11) && (!(strpos($buffer,"\n",$i+11)===FALSE))) {
            $new_line_pos = strpos($buffer, "\n", $i + 10);
            $sql_delimiter = substr($buffer, $i+10, $new_line_pos - $i -10);
            $i= $new_line_pos + 1;
