@@ -3,11 +3,14 @@
 /**
  * phpMyAdmin Language Loading File
  *
- * @version $Id: select_lang.lib.php 10430 2007-06-10 19:28:56Z lem9 $
+ * @version $Id: select_lang.lib.php 11326 2008-06-17 21:32:48Z lem9 $
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
- * trys to find the language to use
+ * tries to find the language to use
  *
  * @uses    $GLOBALS['cfg']['lang']
  * @uses    $GLOBALS['cfg']['DefaultLang']
@@ -414,8 +417,9 @@ if (empty($GLOBALS['convcharset'])) {
     if (isset($_COOKIE['pma_charset'])) {
         $GLOBALS['convcharset'] = $_COOKIE['pma_charset'];
     } else {
-        // session.save_path might point to a bad folder
-        $convcharset = isset($GLOBALS['cfg']['DefaultCharset']) ? $GLOBALS['cfg']['DefaultCharset'] : 'en-utf-8';
+        // session.save_path might point to a bad folder, in which case
+        // $GLOBALS['cfg'] would not exist
+        $convcharset = isset($GLOBALS['cfg']['DefaultCharset']) ? $GLOBALS['cfg']['DefaultCharset'] : 'utf-8';
     }
 }
 
